@@ -54,16 +54,24 @@ module RuboCop
           end
         end
 
+        def on_or(node)
+          return unless node.lhs.falsey_literal?
+
+          add_offense(node.lhs) do |corrector|
+            # Don't autocorrect `'foo' && return` because having `return` as
+            # the leftmost node can lead to a void value expression syntax error.
+            next if node.rhs.type?(:return, :break, :next)
+
+            corrector.replace(node, node.rhs.source)
+          end
+        end
+
         def on_if(node)
           cond = condition(node)
 
-          if node.unless?
-            correct_if_node(node, cond, true) if cond.falsey_literal?
-            correct_if_node(node, cond, false) if cond.truthy_literal?
-          else
-            correct_if_node(node, cond, true) if cond.truthy_literal?
-            correct_if_node(node, cond, false) if cond.falsey_literal?
-          end
+          return unless cond.falsey_literal? || cond.truthy_literal?
+
+          correct_if_node(node, cond)
         end
 
         def on_while(node)
@@ -127,7 +135,9 @@ module RuboCop
         # rubocop:enable Metrics/AbcSize
 
         def on_case(case_node)
-          if case_node.condition
+          if (cond = case_node.condition)
+            return if !cond.falsey_literal? && !cond.truthy_literal?
+
             check_case(case_node)
           else
             case_node.when_branches.each do |when_node|
@@ -232,27 +242,37 @@ module RuboCop
           )
         end
 
-        # rubocop:disable Metrics/AbcSize, Metrics/MethodLength
-        def correct_if_node(node, cond, result)
-          if result
-            add_offense(cond) do |corrector|
-              corrector.replace(node, node.if_branch.source)
-            end
-          elsif node.elsif_conditional?
-            add_offense(cond) do |corrector|
-              corrector.replace(node, "#{node.else_branch.source.sub('elsif', 'if')}\nend")
-            end
-          elsif node.else? || node.ternary?
-            add_offense(cond) do |corrector|
-              corrector.replace(node, node.else_branch.source)
-            end
+        def condition_evaluation?(node, cond)
+          if node.unless?
+            cond.falsey_literal?
           else
-            add_offense(cond) do |corrector|
-              corrector.remove(node)
-            end
+            cond.truthy_literal?
           end
         end
-        # rubocop:enable Metrics/AbcSize, Metrics/MethodLength
+
+        # rubocop:disable Metrics/AbcSize, Metrics/MethodLength, Metrics/CyclomaticComplexity, Metrics/PerceivedComplexity
+        def correct_if_node(node, cond)
+          result = condition_evaluation?(node, cond)
+
+          new_node = if node.elsif? && result
+                       "else\n  #{range_with_comments(node.if_branch).source}"
+                     elsif node.elsif? && !result
+                       "else\n  #{node.else_branch.source}"
+                     elsif node.if_branch && result
+                       node.if_branch.source
+                     elsif node.elsif_conditional?
+                       "#{node.else_branch.source.sub('elsif', 'if')}\nend"
+                     elsif node.else? || node.ternary?
+                       node.else_branch.source
+                     else
+                       '' # Equivalent to removing the node
+                     end
+
+          add_offense(cond) do |corrector|
+            corrector.replace(node, new_node)
+          end
+        end
+        # rubocop:enable Metrics/AbcSize, Metrics/MethodLength, Metrics/CyclomaticComplexity, Metrics/PerceivedComplexity
       end
     end
   end
